@@ -12,6 +12,7 @@ pub struct GitBranchConfig<'a> {
     pub truncation_symbol: &'a str,
     pub only_attached: bool,
     pub always_show_remote: bool,
+    pub ignore_branches: Vec<&'a str>,
     pub disabled: bool,
 }
 
@@ -25,6 +26,7 @@ impl<'a> Default for GitBranchConfig<'a> {
             truncation_symbol: "…",
             only_attached: false,
             always_show_remote: false,
+            ignore_branches: vec![],
             disabled: false,
         }
     }
