@@ -15,6 +15,7 @@ pub struct ShellConfig<'a> {
     pub tcsh_indicator: &'a str,
     pub nu_indicator: &'a str,
     pub xonsh_indicator: &'a str,
+    pub cmd_indicator: &'a str,
     pub unknown_indicator: &'a str,
     pub style: &'a str,
     pub disabled: bool,
@@ -33,6 +34,7 @@ impl<'a> Default for ShellConfig<'a> {
             tcsh_indicator: "tsh",
             nu_indicator: "nu",
             xonsh_indicator: "xsh",
+            cmd_indicator: "cmd",
             unknown_indicator: "",
             style: "white bold",
             disabled: true,
