@@ -45,6 +45,7 @@ pub const PROMPT_ORDER: &[&str] = &[
     "elm",
     "erlang",
     "golang",
+    "haskell",
     "helm",
     "java",
     "julia",
@@ -69,6 +70,7 @@ pub const PROMPT_ORDER: &[&str] = &[
     "vagrant",
     "zig",
     // ↑ Toolchain version modules ↑
+    "buf",
     "nix_shell",
     "conda",
     "memory_usage",
