@@ -64,12 +64,13 @@ fn get_aws_region_from_config(context: &Context, aws_profile: Option<&str>) -> O
 
 fn get_aws_profile_and_region(context: &Context) -> (Option<Profile>, Option<Region>) {
     let profile_env_vars = vec!["AWSU_PROFILE", "AWS_VAULT", "AWSUME_PROFILE", "AWS_PROFILE"];
+    let region_env_vars = vec!["AWS_REGION", "AWS_DEFAULT_REGION"];
     let profile = profile_env_vars
         .iter()
         .find_map(|env_var| context.get_env(env_var));
-    let region = context
-        .get_env("AWS_DEFAULT_REGION")
-        .or_else(|| context.get_env("AWS_REGION"));
+    let region = region_env_vars
+        .iter()
+        .find_map(|env_var| context.get_env(env_var));
     match (profile, region) {
         (Some(p), Some(r)) => (Some(p), Some(r)),
         (None, Some(r)) => (None, Some(r)),
@@ -111,15 +112,22 @@ fn get_credentials_duration(context: &Context, aws_profile: Option<&Profile>) ->
     Some(expiration_date.timestamp() - chrono::Local::now().timestamp())
 }
 
-fn alias_region(region: String, aliases: &HashMap<String, &str>) -> String {
-    match aliases.get(&region) {
-        None => region,
-        Some(alias) => (*alias).to_string(),
-    }
+fn alias_name(name: Option<String>, aliases: &HashMap<String, &str>) -> Option<String> {
+    name.as_ref()
+        .and_then(|n| aliases.get(n))
+        .map(|&a| a.to_string())
+        .or(name)
 }
 
-fn get_credential_process(context: &Context, aws_profile: Option<&Profile>) -> Option<String> {
-    let contents = read_file(get_config_file_path(context)?).ok()?;
+fn has_credential_process_or_sso(context: &Context, aws_profile: Option<&Profile>) -> bool {
+    let fp = match get_config_file_path(context) {
+        Some(fp) => fp,
+        None => return false,
+    };
+    let contents = match read_file(fp) {
+        Ok(contents) => contents,
+        Err(_) => return false,
+    };
 
     let profile_line = if let Some(aws_profile) = aws_profile {
         format!("[profile {}]", aws_profile)
@@ -127,15 +135,12 @@ fn get_credential_process(context: &Context, aws_profile: Option<&Profile>) -> O
         "[default]".to_string()
     };
 
-    let cred_proc_line = contents
+    contents
         .lines()
         .skip_while(|line| line != &profile_line)
         .skip(1)
         .take_while(|line| !line.starts_with('['))
-        .find(|line| line.starts_with("credential_process"))?;
-
-    let cred_proc = cred_proc_line.split('=').nth(1)?.trim();
-    Some(cred_proc.to_string())
+        .any(|line| line.starts_with("credential_process") || line.starts_with("sso_start_url"))
 }
 
 fn get_defined_credentials(context: &Context, aws_profile: Option<&Profile>) -> Option<String> {
@@ -181,18 +186,12 @@ pub fn module<'a>(context: &'a Context) -> Option<Module<'a>> {
     }
 
     // only display if credential_process is defined or has valid credentials
-    if get_credential_process(context, aws_profile.as_ref()).is_none()
+    if !has_credential_process_or_sso(context, aws_profile.as_ref())
         && get_defined_credentials(context, aws_profile.as_ref()).is_none()
     {
         return None;
     }
 
-    let mapped_region = if let Some(aws_region) = aws_region {
-        Some(alias_region(aws_region, &config.region_aliases))
-    } else {
-        None
-    };
-
     let duration = {
         get_credentials_duration(context, aws_profile.as_ref()).map(|duration| {
             if duration > 0 {
@@ -203,6 +202,10 @@ pub fn module<'a>(context: &'a Context) -> Option<Module<'a>> {
         })
     };
 
+    let mapped_region = alias_name(aws_region, &config.region_aliases);
+
+    let mapped_profile = alias_name(aws_profile, &config.profile_aliases);
+
     let parsed = StringFormatter::new(config.format).and_then(|formatter| {
         formatter
             .map_meta(|variable, _| match variable {
@@ -214,7 +217,7 @@ pub fn module<'a>(context: &'a Context) -> Option<Module<'a>> {
                 _ => None,
             })
             .map(|variable| match variable {
-                "profile" => aws_profile.as_ref().map(Ok),
+                "profile" => mapped_profile.as_ref().map(Ok),
                 "region" => mapped_region.as_ref().map(Ok),
                 "duration" => duration.as_ref().map(Ok),
                 _ => None,
@@ -287,7 +290,7 @@ mod tests {
             .collect();
         let expected = Some(format!(
             "on {}",
-            Color::Yellow.bold().paint("☁️  (ap-northeast-1) ")
+            Color::Yellow.bold().paint("☁️  (ap-northeast-2) ")
         ));
 
         assert_eq!(expected, actual);
@@ -369,6 +372,46 @@ mod tests {
         assert_eq!(expected, actual);
     }
 
+    #[test]
+    fn profile_set_with_alias() {
+        let actual = ModuleRenderer::new("aws")
+            .env("AWS_PROFILE", "CORPORATION-CORP_astronauts_ACCESS_GROUP")
+            .env("AWS_REGION", "ap-northeast-2")
+            .env("AWS_ACCESS_KEY_ID", "dummy")
+            .config(toml::toml! {
+                [aws.profile_aliases]
+                CORPORATION-CORP_astronauts_ACCESS_GROUP = "astro"
+            })
+            .collect();
+        let expected = Some(format!(
+            "on {}",
+            Color::Yellow.bold().paint("☁️  astro (ap-northeast-2) ")
+        ));
+
+        assert_eq!(expected, actual);
+    }
+
+    #[test]
+    fn region_and_profile_both_set_with_alias() {
+        let actual = ModuleRenderer::new("aws")
+            .env("AWS_PROFILE", "CORPORATION-CORP_astronauts_ACCESS_GROUP")
+            .env("AWS_REGION", "ap-southeast-2")
+            .env("AWS_ACCESS_KEY_ID", "dummy")
+            .config(toml::toml! {
+                [aws.profile_aliases]
+                CORPORATION-CORP_astronauts_ACCESS_GROUP = "astro"
+                [aws.region_aliases]
+                ap-southeast-2 = "au"
+            })
+            .collect();
+        let expected = Some(format!(
+            "on {}",
+            Color::Yellow.bold().paint("☁️  astro (au) ")
+        ));
+
+        assert_eq!(expected, actual);
+    }
+
     #[test]
     fn credentials_file_is_ignored_when_is_directory() -> io::Result<()> {
         let dir = tempfile::tempdir()?;
@@ -805,6 +848,37 @@ credential_process = /opt/bin/awscreds-retriever
         dir.close()
     }
 
+    #[test]
+    fn sso_set() -> io::Result<()> {
+        let dir = tempfile::tempdir()?;
+        let config_path = dir.path().join("config");
+        let mut file = File::create(&config_path)?;
+
+        file.write_all(
+            "[default]
+region = ap-northeast-2
+sso_start_url = https://starship.rs/sso
+sso_region = <SSO-Default-Region>
+sso_account_id = <AWS ACCOUNT ID>
+sso_role_name = <AWS-ROLE-NAME>
+"
+            .as_bytes(),
+        )?;
+
+        file.sync_all()?;
+
+        let actual = ModuleRenderer::new("aws")
+            .env("AWS_CONFIG_FILE", config_path.to_string_lossy().as_ref())
+            .collect();
+        let expected = Some(format!(
+            "on {}",
+            Color::Yellow.bold().paint("☁️  (ap-northeast-2) ")
+        ));
+
+        assert_eq!(expected, actual);
+        dir.close()
+    }
+
     #[test]
     fn access_key_env_var_set() {
         let actual = ModuleRenderer::new("aws")
