@@ -10,6 +10,12 @@ use crate::configs::kubernetes::KubernetesConfig;
 use crate::formatter::StringFormatter;
 use crate::utils;
 
+struct KubeCtxComponents {
+    user: Option<String>,
+    namespace: Option<String>,
+    cluster: Option<String>,
+}
+
 fn get_kube_context(filename: path::PathBuf) -> Option<String> {
     let contents = utils::read_file(filename).ok()?;
 
@@ -27,7 +33,10 @@ fn get_kube_context(filename: path::PathBuf) -> Option<String> {
     Some(current_ctx.to_string())
 }
 
-fn get_kube_ns(filename: path::PathBuf, current_ctx: String) -> Option<String> {
+fn get_kube_ctx_component(
+    filename: path::PathBuf,
+    current_ctx: String,
+) -> Option<KubeCtxComponents> {
     let contents = utils::read_file(filename).ok()?;
 
     let yaml_docs = YamlLoader::load_from_str(&contents).ok()?;
@@ -36,18 +45,41 @@ fn get_kube_ns(filename: path::PathBuf, current_ctx: String) -> Option<String> {
     }
     let conf = &yaml_docs[0];
 
-    let ns = conf["contexts"].as_vec().and_then(|contexts| {
+    let ctx_yaml = conf["contexts"].as_vec().and_then(|contexts| {
         contexts
             .iter()
             .filter_map(|ctx| Some((ctx, ctx["name"].as_str()?)))
             .find(|(_, name)| *name == current_ctx)
-            .and_then(|(ctx, _)| ctx["context"]["namespace"].as_str())
-    })?;
+    });
 
-    if ns.is_empty() {
-        return None;
-    }
-    Some(ns.to_owned())
+    let ctx_components = KubeCtxComponents {
+        user: ctx_yaml
+            .and_then(|(ctx, _)| ctx["context"]["user"].as_str())
+            .and_then(|s| {
+                if s.is_empty() {
+                    return None;
+                }
+                Some(s.to_owned())
+            }),
+        namespace: ctx_yaml
+            .and_then(|(ctx, _)| ctx["context"]["namespace"].as_str())
+            .and_then(|s| {
+                if s.is_empty() {
+                    return None;
+                }
+                Some(s.to_owned())
+            }),
+        cluster: ctx_yaml
+            .and_then(|(ctx, _)| ctx["context"]["cluster"].as_str())
+            .and_then(|s| {
+                if s.is_empty() {
+                    return None;
+                }
+                Some(s.to_owned())
+            }),
+    };
+
+    Some(ctx_components)
 }
 
 fn get_kube_context_name<'a>(config: &'a KubernetesConfig, kube_ctx: &'a str) -> Cow<'a, str> {
@@ -86,8 +118,22 @@ pub fn module<'a>(context: &'a Context) -> Option<Module<'a>> {
 
     let kube_ctx = env::split_paths(&kube_cfg).find_map(get_kube_context)?;
 
-    let kube_ns =
-        env::split_paths(&kube_cfg).find_map(|filename| get_kube_ns(filename, kube_ctx.clone()));
+    let ctx_components: Vec<Option<KubeCtxComponents>> = env::split_paths(&kube_cfg)
+        .map(|filename| get_kube_ctx_component(filename, kube_ctx.clone()))
+        .collect();
+
+    let kube_user = ctx_components.iter().find(|&ctx| match ctx {
+        Some(kube) => kube.user.is_some(),
+        None => false,
+    });
+    let kube_ns = ctx_components.iter().find(|&ctx| match ctx {
+        Some(kube) => kube.namespace.is_some(),
+        None => false,
+    });
+    let kube_cluster = ctx_components.iter().find(|&ctx| match ctx {
+        Some(kube) => kube.cluster.is_some(),
+        None => false,
+    });
 
     let parsed = StringFormatter::new(config.format).and_then(|formatter| {
         formatter
@@ -101,7 +147,26 @@ pub fn module<'a>(context: &'a Context) -> Option<Module<'a>> {
             })
             .map(|variable| match variable {
                 "context" => Some(Ok(get_kube_context_name(&config, &kube_ctx))),
-                "namespace" => kube_ns.as_ref().map(|s| Ok(Cow::Borrowed(s.as_str()))),
+
+                "namespace" => kube_ns.and_then(|ctx| {
+                    ctx.as_ref().map(|kube| {
+                        // unwrap is safe as kube_ns only holds kube.namespace.is_some()
+                        Ok(Cow::Borrowed(kube.namespace.as_ref().unwrap().as_str()))
+                    })
+                }),
+                "user" => kube_user.and_then(|ctx| {
+                    ctx.as_ref().map(|kube| {
+                        // unwrap is safe as kube_user only holds kube.user.is_some()
+                        Ok(Cow::Borrowed(kube.user.as_ref().unwrap().as_str()))
+                    })
+                }),
+                "cluster" => kube_cluster.and_then(|ctx| {
+                    ctx.as_ref().map(|kube| {
+                        // unwrap is safe as kube_cluster only holds kube.cluster.is_some()
+                        Ok(Cow::Borrowed(kube.cluster.as_ref().unwrap().as_str()))
+                    })
+                }),
+
                 _ => None,
             })
             .parse(None, Some(context))
@@ -463,4 +528,162 @@ users: []
 
         dir.close()
     }
+
+    #[test]
+    fn test_kube_user() -> io::Result<()> {
+        let dir = tempfile::tempdir()?;
+
+        let filename = dir.path().join("config");
+
+        let mut file = File::create(&filename)?;
+        file.write_all(
+            b"
+apiVersion: v1
+clusters: []
+contexts:
+  - context:
+      cluster: test_cluster
+      user: test_user
+      namespace: test_namespace
+    name: test_context
+current-context: test_context
+kind: Config
+preferences: {}
+users: []
+",
+        )?;
+        file.sync_all()?;
+
+        let actual = ModuleRenderer::new("kubernetes")
+            .path(dir.path())
+            .env("KUBECONFIG", filename.to_string_lossy().as_ref())
+            .config(toml::toml! {
+                [kubernetes]
+                format = "($user)"
+                disabled = false
+            })
+            .collect();
+
+        let expected = Some("test_user".to_string());
+        assert_eq!(expected, actual);
+        dir.close()
+    }
+
+    #[test]
+    fn test_kube_cluster() -> io::Result<()> {
+        let dir = tempfile::tempdir()?;
+
+        let filename = dir.path().join("config");
+
+        let mut file = File::create(&filename)?;
+        file.write_all(
+            b"
+apiVersion: v1
+clusters: []
+contexts:
+  - context:
+      cluster: test_cluster
+      user: test_user
+      namespace: test_namespace
+    name: test_context
+current-context: test_context
+kind: Config
+preferences: {}
+users: []
+",
+        )?;
+        file.sync_all()?;
+
+        let actual = ModuleRenderer::new("kubernetes")
+            .path(dir.path())
+            .env("KUBECONFIG", filename.to_string_lossy().as_ref())
+            .config(toml::toml! {
+                [kubernetes]
+                format = "($cluster)"
+                disabled = false
+            })
+            .collect();
+
+        let expected = Some("test_cluster".to_string());
+        assert_eq!(expected, actual);
+        dir.close()
+    }
+
+    #[test]
+    fn test_kube_user_missing() -> io::Result<()> {
+        let dir = tempfile::tempdir()?;
+
+        let filename = dir.path().join("config");
+
+        let mut file = File::create(&filename)?;
+        file.write_all(
+            b"
+apiVersion: v1
+clusters: []
+contexts:
+  - context:
+      cluster: test_cluster
+      namespace: test_namespace
+    name: test_context
+current-context: test_context
+kind: Config
+preferences: {}
+users: []
+",
+        )?;
+        file.sync_all()?;
+
+        let actual = ModuleRenderer::new("kubernetes")
+            .path(dir.path())
+            .env("KUBECONFIG", filename.to_string_lossy().as_ref())
+            .config(toml::toml! {
+                [kubernetes]
+                format = "$symbol($user )($cluster )($namespace)"
+                disabled = false
+            })
+            .collect();
+
+        let expected = Some("☸ test_cluster test_namespace".to_string());
+        assert_eq!(expected, actual);
+        dir.close()
+    }
+
+    #[test]
+    fn test_kube_cluster_missing() -> io::Result<()> {
+        let dir = tempfile::tempdir()?;
+
+        let filename = dir.path().join("config");
+
+        let mut file = File::create(&filename)?;
+        file.write_all(
+            b"
+apiVersion: v1
+clusters: []
+contexts:
+  - context:
+      user: test_user
+      namespace: test_namespace
+    name: test_context
+current-context: test_context
+kind: Config
+preferences: {}
+users: []
+",
+        )?;
+        file.sync_all()?;
+
+        let actual = ModuleRenderer::new("kubernetes")
+            .path(dir.path())
+            .env("KUBECONFIG", filename.to_string_lossy().as_ref())
+            .config(toml::toml! {
+                [kubernetes]
+                format = "$symbol($user )($cluster )($namespace)"
+                disabled = false
+            })
+            .collect();
+
+        let expected = Some("☸ test_user test_namespace".to_string());
+        assert_eq!(expected, actual);
+        dir.close()
+    }
 }
